import os
import pep8
import glob
import unittest
import subprocess

traindir = os.path.join('..', 'citrain')
manualdir = os.path.join(traindir, 'manual')

def call(args):
    return ''.join(subprocess.Popen(
        args, stderr=subprocess.PIPE, stdout=subprocess.PIPE
    ).communicate())


EXCLUDES = [
    '.xml.tmpl',
    'jenkins-templates',
    ]


def exclude(filename):
    for ex in EXCLUDES:
        if ex in filename:
            return True
    return False


class Pep8ConformanceTestCase(unittest.TestCase):
    def test_pep8_conformance(self):
        pep8style = pep8.StyleGuide(show_source=True)
        #pep8style.input_dir('..') # FIXME: enable this later.
        for root, _, files in os.walk(traindir):
            for filename in files:
                filepath = os.path.join(root, filename)
                if os.path.isfile(filepath) and not exclude(filepath):
                    pep8style.check_files([filepath])
        self.assertEqual(
            pep8style.options.report.total_errors,
            0,
            "Unexpected output from pep8.")

    def test_pyflakes_conformance(self):
        output = call(['pyflakes'] +
                      glob.glob(os.path.join(traindir, '*')) +
                      glob.glob(os.path.join(manualdir, '*')))
        print(output)
        self.assertEqual(len(output), 0, "Unexpected output from pyflakes.")
