import os

from tests.unit import CITrainScriptTestCase

EXPECTED_BUILD_TEMPLATE_RESULT = """\
<?xml version=\'1.0\' encoding=\'UTF-8\'?>
<project>
  <actions/>
  <description>Build and check "ubuntu/landing-123" projects</description>
  <logRotator>
    <daysToKeep>15</daysToKeep>
    <numToKeep>-1</numToKeep>
    <artifactDaysToKeep>-1</artifactDaysToKeep>
    <artifactNumToKeep>-1</artifactNumToKeep>
  </logRotator>
  <keepDependencies>false</keepDependencies>
  <properties>
    <hudson.security.AuthorizationMatrixProperty>
      <permission>hudson.model.Item.Read:ubuntu-core-dev</permission>
      <permission>hudson.model.Item.Cancel:ubuntu-core-dev</permission>
      <permission>hudson.model.Item.Build:ubuntu-core-dev</permission>
      <permission>hudson.model.Item.Read:canonical-ci-eng</permission>
      <permission>hudson.model.Item.Cancel:canonical-ci-eng</permission>
      <permission>hudson.model.Item.Build:canonical-ci-eng</permission>
      <permission>hudson.model.Item.Read:ci-train-users</permission>
      <permission>hudson.model.Item.Cancel:ci-train-users</permission>
      <permission>hudson.model.Item.Build:ci-train-users</permission>
      <permission>hudson.model.Item.Read:ubuntu-unity</permission>
      <permission>hudson.model.Item.Cancel:ubuntu-unity</permission>
      <permission>hudson.model.Item.Build:ubuntu-unity</permission>
    </hudson.security.AuthorizationMatrixProperty>
    <hudson.model.ParametersDefinitionProperty>
      <parameterDefinitions>
        <hudson.model.StringParameterDefinition>
          <name>PACKAGES_TO_REBUILD</name>
          <description>Enter source package names separated by spaces. A new \
build will be submitted to this silo containing all merge proposals attached \
to this landing request. It is an error to specify a source package name that \
has no merge proposals listed here. (leave blank for all)</description>
          <defaultValue></defaultValue>
        </hudson.model.StringParameterDefinition>
        <hudson.model.BooleanParameterDefinition>
          <name>WATCH_ONLY</name>
          <description>Does not perform build, only watch the current ppa, \
run tests, and register builds for publishing.</description>
          <defaultValue>false</defaultValue>
        </hudson.model.BooleanParameterDefinition>
        <hudson.model.BooleanParameterDefinition>
          <name>FORCE_REBUILD</name>
          <description>Force rebuilding components associated to a MP even \
if there is no diff with dest or if latest version in destination archive \
isn\'t in targeted branches.</description>
          <defaultValue>false</defaultValue>
        </hudson.model.BooleanParameterDefinition>
        <hudson.model.BooleanParameterDefinition>
          <name>IGNORE_STEP</name>
          <description>Allow build to proceed even if it is being run out \
of the expected order (check this if you are rebuilding a whole silo already \
built, or even already published).</description>
          <defaultValue>false</defaultValue>
        </hudson.model.BooleanParameterDefinition>
        <hudson.model.BooleanParameterDefinition>
          <name>IGNORE_MISSING_TWINS</name>
          <description>(Usually irrelevant) Ignore missing \'twin\' packages \
for the selected list (like those having -gles duplicates).</description>
          <defaultValue>false</defaultValue>
        </hudson.model.BooleanParameterDefinition>
        <hudson.model.BooleanParameterDefinition>
          <name>DONT_REORDER_PREREQS</name>
          <description>Don\'t forcefully reorder branches if prerequisites \
are used - leave it up to the lander.</description>
          <defaultValue>false</defaultValue>
        </hudson.model.BooleanParameterDefinition>
        <hudson.model.BooleanParameterDefinition>
          <name>TAKE_WHOLE_COMMIT_MESSAGE</name>
          <description>Use whole commit message when generating changelog, \
not just the brief part.</description>
          <defaultValue>false</defaultValue>
        </hudson.model.BooleanParameterDefinition>
        <hudson.model.BooleanParameterDefinition>
          <name>DEBUG</name>
          <description>Print extra debugging information in the \
log.</description>
          <defaultValue>false</defaultValue>
        </hudson.model.BooleanParameterDefinition>
      </parameterDefinitions>
    </hudson.model.ParametersDefinitionProperty>
  </properties>
  <scm class="hudson.scm.NullSCM"/>
  <canRoam>false</canRoam>
  <disabled>false</disabled>
  <blockBuildWhenDownstreamBuilding>false</blockBuildWhenDownstreamBuilding>
  <blockBuildWhenUpstreamBuilding>false</blockBuildWhenUpstreamBuilding>
  <triggers class="vector"/>
  <builders>
    <hudson.tasks.Shell>
      <command>#!/bin/bash -eu
export LANG=en_US.UTF-8
export WORKSPACE="$PWD"

cd /var/lib/jenkins/silos/ubuntu/landing-123

~/citrain/citrain/build
</command>
    </hudson.tasks.Shell>
    <hudson.tasks.Shell>
      <command>#!/bin/bash -eu
export LANG=en_US.UTF-8
export WORKSPACE="$PWD"

cd /var/lib/jenkins/silos/ubuntu/landing-123

~/citrain/citrain/mark-as-builtchecked
</command>
    </hudson.tasks.Shell>
  </builders>
  <publishers>
  </publishers>
  <buildWrappers>
    <org.jenkinsci.plugins.builduser.BuildUser \
plugin="build-user-vars-plugin@1.3"/>
  </buildWrappers>
</project>
"""


class PublisherTestCase(CITrainScriptTestCase):
    scriptname = 'manual' + os.sep + 'setup-citrain'

    def test_template_names(self):
        self.assertTrue(self.script.template)
        self.assertEqual(self.script.template('foobar'), 'foobar.xml.tmpl')

    def test_load_template(self):
        self.assertTrue(self.script.load_template)
        CONTEXT = {
            'SILO_NAME': 'ubuntu/landing-123',
            'SILOS_DIR': '/var/lib/jenkins/silos',
            'BINDIR':    '~/citrain/citrain',
        }
        self.assertEqual(
            self.script.load_template('build.xml.tmpl', CONTEXT),
            EXPECTED_BUILD_TEMPLATE_RESULT)
